import React from "react"
import { graphql, PageProps } from "gatsby"
import { twMerge } from "tailwind-merge"
import {
    Layout,
    Content,
    Sections,
    Toc,
} from "@onegeo-suite/gatsby-theme-onegeo"

import { PageContext } from "../context/page"
interface ISection {
    sections_id: string[] | []
}
interface IPageContext {
    directus: {
        pages: {
            id: string
            title: string
            content: string
            slug: string
            sections: ISection[] | []
            toc: boolean
            options?: any
        }
    }
}
// [&_h1]:scroll-mt-28  [&_h2]:scroll-mt-28  [&_h3]:scroll-mt-28  [&_h4]:scroll-mt-28 text-secondary-content
const PageTemplate = ({ data }: PageProps<IPageContext>) => {
    const news = data.directus.pages[0]
    const { title, content, sections, toc = false } = news

    const idsSections = sections.map((section: any) => section.sections_id.id)

    const options = news.options ?? {}
    const oClass = options.class || {}
    const oContext = options.context || {}

    return (
        <PageContext.Provider value={oContext}>
            <Layout theme={options.theme}>
                <Content
                    className={twMerge(
                        "mt-8 flex  flex-wrap gap-6 md:flex-nowrap",
                        toc ? "max-w-6xl" : "max-w-4xl",
                        oClass.main
                    )}
                >
                    <div
                        className={twMerge(
                            "bg-base-100 rounded-xl p-6 shadow-lg",
                            oClass.body
                        )}
                    >
                        {content && (
                            <div
                                className={twMerge(
                                    "prose lg:prose-lg prose-headings:scroll-mt-24 max-w-4xl",
                                    oClass.content
                                )}
                                dangerouslySetInnerHTML={{ __html: content }}
                            ></div>
                        )}
                        {Object.keys(idsSections).length !== 0 && (
                            <Sections ids={idsSections} />
                        )}
                    </div>
                    {toc ? <Toc /> : <></>}
                </Content>
            </Layout>
        </PageContext.Provider>
    )
}

export default PageTemplate

export const query = graphql`
    query ($id: DirectusData_GraphQLStringOrFloat!) {
        directus {
            pages(filter: { id: { _eq: $id } }) {
                sections {
                    sections_id {
                        id
                    }
                }
                content
                id
                title
                slug
                toc
                options
            }
        }
    }
`
